Gemma DRC CMIS
========================================================

.. note:: This package is not ment to be run seperate from gemma-documentregistratiecomponent.

.. image:: https://img.shields.io/pypi/v/drc-cmis.svg?style=for-the-badge
           :alt: PyPi
           :target: https://pypi.org/project/drc-cmis/
.. image:: https://img.shields.io/travis/GemeenteUtrecht/gemma-drc-cmis.svg?style=for-the-badge
           :alt: Travis
           :target: https://travis-ci.org/GemeenteUtrecht/gemma-drc-cmis
.. image:: https://img.shields.io/codecov/c/gh/GemeenteUtrecht/gemma-drc-cmis.svg?style=for-the-badge
           :alt: Codecov
           :target: https://codecov.io/gh/GemeenteUtrecht/gemma-drc-cmis

.. contents:: **Table of Contents**
    :backlinks: none

Installation
------------

Gemma DRC CMIS is distributed on `PyPI <https://pypi.org>`_ as a universal
wheel and is available on Linux/macOS and Windows and supports
Python 2.7/3.5+ and PyPy.

.. code-block:: bash

    $ pip install gemma-drc-cmis


Add to installed apps

.. code-block:: bash

    INSTALLED_APPS = [
        ...
        'drc_cmis',
        ...
    ]

License
-------

Gemma DRC CMIS is distributed under the terms of the
`MIT License <https://choosealicense.com/licenses/mit>`_.
